@@ -14,5 +14,5 @@ def install():
     #    f.write('@echo off\n"' + str(executable) + '" "' + root + '__main__.py' + '"\npause')
     subprocess.check_call([sys.executable, "-m", "pip", "install", "--no-index", "--find-links", root+"wheels/pyGpufit-1.2.0-py2.py3-none-any.whl", "pyGpufit"])
     subprocess.check_call([sys.executable, "-m", "pip", "install", "--no-index", "--find-links", root+"wheels/dill-0.3.6-py3-none-any.whl", "pyGpufit"])
-    subprocess.check_call([sys.executable, "-m", "pip", "install", root+"wheels/pyimgui_wheels-2.0.1-cp38-cp38-none-any.whl", "pyimgui-wheels"])
+    subprocess.check_call([sys.executable, "-m", "pip", "install", root+"wheels/pyimgui_wheels-2.0.1-cp38-none-any.whl", "pyimgui-wheels"])
 
